"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var createHash = require("sha.js");

var WebpackSHAHash = function () {
    /**
     * Parse the options and initialize the plugin.
     * @param options the options if any
     */
    function WebpackSHAHash() {
        var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

        _classCallCheck(this, WebpackSHAHash);

        // Hashing algorithm
        if (!options.hasOwnProperty("hashingAlgorithm")) {
            options.hashingAlgorithm = "sha256"; // default
        }

        this.hashingAlgorithm = options.hashingAlgorithm;

        try {
            createHash(this.hashingAlgorithm);
        } catch (e) {
            throw new Error("You have most probably provided an invalid value for the 'hashingAlgorithm' option of the WebpackSHAHash plugin! Error details: " + e.stack + "\n -----------");
        }

        // remove the option from the object once processed (so that we can identify if unknown options have been passed)
        delete options.hashingAlgorithm;

        // Check if unknown options were passed (i.e., fail fast and be helpful)
        for (var prop in options) {
            if (options.hasOwnProperty(prop)) {
                throw new Error("You have passed an unknown option to the WebpackSHAHash plugin: " + prop);
            }
        }
    }

    _createClass(WebpackSHAHash, [{
        key: "compareModules",
        value: function compareModules(a, b) {
            var retVal = 0;

            if (a.resource < b.resource) {
                retVal = -1;
            } else if (a.resource > b.resource) {
                retVal = 1;
            }

            return retVal;
        }
    }, {
        key: "getModuleSource",
        value: function getModuleSource(module) {
            var source = module._source || {};

            return source._value || "";
        }
    }, {
        key: "concatenateSource",
        value: function concatenateSource(result, moduleSource) {
            return result + moduleSource;
        }
    }, {
        key: "generateHash",
        value: function generateHash(content) {
            return createHash(this.hashingAlgorithm).update(content, "utf8").digest("hex");
        }

        /**
         * Called by Webpack which gives a referencer to its compiler object.
         * Reference: https://github.com/webpack/docs/wiki/plugins
         * @param compiler the Webpack compiler object
         */

    }, {
        key: "apply",
        value: function apply(compiler) {
            var _this = this;

            compiler.plugin("compilation", function (compilation) {
                compilation.plugin("chunk-hash", function (chunk, chunkHash) {
                    var chunkModules = chunk.mapModules ? chunk.mapModules(function (c) {
                        return c;
                    }) : chunk.modules;
                    var source = chunkModules.sort(_this.compareModules).map(_this.getModuleSource).reduce(_this.concatenateSource, ""); // we provide an initialValue in case there is an empty module source. Ref: http://es5.github.io/#x15.4.4.21
                    var calculatedChunkHash = _this.generateHash(source);

                    chunkHash.digest = function () {
                        return calculatedChunkHash;
                    };
                });
            });
        }
    }]);

    return WebpackSHAHash;
}();

module.exports = WebpackSHAHash;